@@ -15,6 +15,7 @@ from typing import List, Tuple, Union
 import zipfile
 import bsdiff4
 import atexit
+import urllib.parse
 
 
 # CommonClient import first to trigger ModuleUpdater
@@ -67,8 +68,8 @@ deathlink_sent_this_death: we interacted with the multiworld on this death, wait
 bt_loc_name_to_id = {}
 bt_itm_name_to_id = {}
 script_version: int = 5
-version: str = "V4.10.1"
-patch_md5: str = "12805129c5684b139aad57a6a421633e"
+version: str = "V4.11.2"
+patch_md5: str = "ca019e19a58d42ed8ad6a331bdad1bf4"
 bt_options = settings.get_settings().banjo_tooie_options
 program = None
 
@@ -292,9 +293,9 @@ class BanjoTooieContext(CommonContext):
     command_processor = BanjoTooieCommandProcessor
     items_handling = 0b111 #full
 
-    def __init__(self, server_address, slot_name, password, ready_callback=None, error_callback=None):
+    def __init__(self, server_address, password, ready_callback=None, error_callback=None):
         super().__init__(server_address, password)
-        self.username = slot_name
+        self.username = urllib.parse.urlparse(server_address).username
         self.ready_callback = ready_callback
         self.error_callback = error_callback
         self.game = "Banjo-Tooie"
@@ -457,24 +458,15 @@ class BanjoTooieContext(CommonContext):
         if cmd == "Connected":
             self.tracker = BanjoTooieItemTracker(self)
             self.slot_data = args.get("slot_data", None)
-            if version != self.slot_data["version"]:
+            if version != self.slot_data["custom_bt_data"]["version"]:
                 logger.error("Your Banjo-Tooie AP does not match with the generated world.")
-                logger.error("Your version: "+version+" | Generated version: "+self.slot_data["version"])
+                logger.error("Your version: "+version+" | Generated version: "+self.slot_data["custom_bt_data"]["version"])
                 # self.event_invalid_game()
                 raise Exception("Your Banjo-Tooie AP does not match with the generated world.\n" +
-                                "Your version: "+version+" | Generated version: "+self.slot_data["version"])
-            self.deathlink_enabled = bool(self.slot_data["death_link"])
-            self.taglink_enabled = bool(self.slot_data["tag_link"])
-
-            self.banjo_tooie_data_package = Utils.load_data_package_for_checksum(
-                    "Banjo-Tooie", self.checksums["Banjo-Tooie"])
-
-            if "location_name_to_id" in self.banjo_tooie_data_package:
-                self.data_package_bt_cache(
-                        self.banjo_tooie_data_package["location_name_to_id"], self.banjo_tooie_data_package["item_name_to_id"])
-                self.n64_sync_task = asyncio.create_task(n64_sync_task(self), name="N64 Sync")
-            else:
-                asyncio.create_task(self.send_msgs([{"cmd": "GetDataPackage", "games": ["Banjo-Tooie"]}]))
+                                "Your version: "+version+" | Generated version: "+self.slot_data["custom_bt_data"]["version"])
+            self.deathlink_enabled = bool(self.slot_data["options"]["death_link"])
+            self.taglink_enabled = bool(self.slot_data["options"]["tag_link"])
+            self.n64_sync_task = asyncio.create_task(n64_sync_task(self), name="N64 Sync")
         elif cmd == "ReceivedItems":
             self.tracker.refresh_items()
             if self.startup == False:
@@ -597,46 +589,45 @@ def get_payload(ctx: BanjoTooieContext):
 
 def get_slot_payload(ctx: BanjoTooieContext):
     payload = json.dumps({
-            "slot_player": ctx.slot_data["player_name"],
-            "slot_seed": ctx.slot_data["seed"],
+            "slot_player": ctx.slot_data["custom_bt_data"]["player_name"],
+            "slot_seed": ctx.slot_data["custom_bt_data"]["seed"],
             "slot_deathlink": ctx.deathlink_enabled,
             "slot_taglink": ctx.taglink_enabled,
-            "slot_tower_of_tragedy": ctx.slot_data["tower_of_tragedy"],
-            "slot_randomize_bk_moves": ctx.slot_data["randomize_bk_moves"],
-            "slot_speed_up_minigames": ctx.slot_data["speed_up_minigames"],
-            "slot_skip_puzzles": ctx.slot_data["skip_puzzles"],
-            "slot_backdoors": ctx.slot_data["backdoors"],
-            "slot_open_hag1": ctx.slot_data["open_hag1"],
-            "slot_randomize_chuffy": ctx.slot_data["randomize_chuffy"],
-            "slot_worlds": ctx.slot_data["worlds"],
-            "slot_world_order": ctx.slot_data["world_order"],
-            "slot_keys": ctx.slot_data["world_keys"],
-            "slot_skip_klungo": ctx.slot_data["skip_klungo"],
-            "slot_victory_condition": ctx.slot_data["victory_condition"],
-            "slot_minigame_hunt_length": ctx.slot_data["minigame_hunt_length"],
-            "slot_boss_hunt_length": ctx.slot_data["boss_hunt_length"],
-            "slot_jinjo_family_rescue_length": ctx.slot_data["jinjo_family_rescue_length"],
-            "slot_token_hunt_length": ctx.slot_data["token_hunt_length"],
+            "slot_tower_of_tragedy": ctx.slot_data["options"]["tower_of_tragedy"],
+            "slot_randomize_bk_moves": ctx.slot_data["options"]["randomize_bk_moves"],
+            "slot_speed_up_minigames": ctx.slot_data["options"]["speed_up_minigames"],
+            "slot_skip_puzzles": ctx.slot_data["options"]["skip_puzzles"],
+            "slot_backdoors": ctx.slot_data["options"]["backdoors"],
+            "slot_open_hag1": ctx.slot_data["options"]["open_hag1"],
+            "slot_randomize_chuffy": ctx.slot_data["options"]["randomize_chuffy"],
+            "slot_world_requirements": ctx.slot_data["custom_bt_data"]["world_requirements"], #??
+            "slot_world_order": ctx.slot_data["custom_bt_data"]["world_order"], #??
+            "slot_skip_klungo": ctx.slot_data["options"]["skip_klungo"],
+            "slot_victory_condition": ctx.slot_data["options"]["victory_condition"],
+            "slot_minigame_hunt_length": ctx.slot_data["options"]["minigame_hunt_length"],
+            "slot_boss_hunt_length": ctx.slot_data["options"]["boss_hunt_length"],
+            "slot_jinjo_family_rescue_length": ctx.slot_data["options"]["jinjo_family_rescue_length"],
+            "slot_token_hunt_length": ctx.slot_data["options"]["token_hunt_length"],
             "slot_version": version,
-            "slot_silo_costs": ctx.slot_data["jamjars_silo_costs"],
-            "slot_preopened_silo": ctx.slot_data["preopened_silos"],
-            "slot_randomize_warp_pads": ctx.slot_data["randomize_warp_pads"],
-            "slot_randomize_silos": ctx.slot_data["randomize_silos"],
-            "slot_zones": ctx.slot_data["loading_zones"],
-            "slot_dialog_character": ctx.slot_data["dialog_character"],
-            "slot_nestsanity": ctx.slot_data["nestsanity"],
-            "slot_hints": ctx.slot_data["hints"],
-            "slot_hints_activated": ctx.slot_data["signpost_hints"],
-            "slot_extra_cheats": ctx.slot_data["extra_cheats"],
-            "slot_easy_canary": ctx.slot_data["easy_canary"],
-            "slot_randomize_signposts": ctx.slot_data["randomize_signposts"],
-            "slot_auto_enable_cheats": ctx.slot_data["auto_enable_cheats"],
-            "slot_cheato_rewards": ctx.slot_data["cheato_rewards"],
-            "slot_honeyb_rewards": ctx.slot_data["honeyb_rewards"],
-            "slot_open_gi_entrance": ctx.slot_data["open_gi_frontdoor"],
-            "slot_randomize_tickets": ctx.slot_data["randomize_tickets"],
-            "slot_randomize_green_relics": ctx.slot_data["randomize_green_relics"],
-            "slot_randomize_beans": ctx.slot_data["randomize_beans"]
+            "slot_silo_costs": ctx.slot_data["custom_bt_data"]["jamjars_silo_costs"],
+            "slot_preopened_silo": ctx.slot_data["custom_bt_data"]["preopened_silos_ids"],
+            "slot_randomize_warp_pads": ctx.slot_data["options"]["randomize_warp_pads"],
+            "slot_randomize_silos": ctx.slot_data["options"]["randomize_silos"],
+            "slot_zones": ctx.slot_data["custom_bt_data"]["loading_zones"],
+            "slot_dialog_character": ctx.slot_data["options"]["dialog_character"],
+            "slot_nestsanity": ctx.slot_data["options"]["nestsanity"],
+            "slot_hints": ctx.slot_data["custom_bt_data"]["hints"],
+            "slot_hints_activated": ctx.slot_data["options"]["signpost_hints"],
+            "slot_extra_cheats": ctx.slot_data["options"]["extra_cheats"],
+            "slot_easy_canary": ctx.slot_data["options"]["easy_canary"],
+            "slot_randomize_signposts": ctx.slot_data["options"]["randomize_signposts"],
+            "slot_auto_enable_cheats": ctx.slot_data["options"]["auto_enable_cheats"],
+            "slot_cheato_rewards": ctx.slot_data["options"]["cheato_rewards"],
+            "slot_honeyb_rewards": ctx.slot_data["options"]["honeyb_rewards"],
+            "slot_open_gi_entrance": ctx.slot_data["options"]["open_gi_frontdoor"],
+            "slot_randomize_tickets": ctx.slot_data["options"]["randomize_tickets"],
+            "slot_randomize_green_relics": ctx.slot_data["options"]["randomize_green_relics"],
+            "slot_randomize_beans": ctx.slot_data["options"]["randomize_beans"]
         })
     ctx.sendSlot = False
     return payload
@@ -863,7 +854,7 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
             ctx.signpost_table = signposts #sets only when transistioning on a new map
         if ctx.signpost_table != signposts:
                 ctx.signpost_table = signposts
-                actual_hints = ctx.slot_data["hints"]
+                actual_hints = ctx.slot_data["custom_bt_data"]["hints"]
                 for locationId, value in signposts.items():
                     if value == True:
                         locs1.append(int(locationId))
@@ -962,17 +953,17 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
             for locationId, value in honeybrewardslist.items():
                 if value == True:
                     locs1.append(int(locationId))
-        if ctx.slot_data["skip_puzzles"] == 1:
+        if ctx.slot_data["options"]["skip_puzzles"] == 1:
             if ctx.worldlist_table != worldslist:
                 ctx.worldlist_table = worldslist
                 for locationId, value in worldslist.items():
                     if value == True:
                         locs1.append(int(locationId))
         #Mumbo Tokens
-        if ctx.slot_data["victory_condition"] == 1 or ctx.slot_data["victory_condition"] == 2 or \
-            ctx.slot_data["victory_condition"] == 3 or ctx.slot_data["victory_condition"] == 4 or \
-            ctx.slot_data["victory_condition"] == 6:
-                locs1 = mumbo_tokens_loc(locs1, ctx.slot_data["victory_condition"])
+        if ctx.slot_data["options"]["victory_condition"] == 1 or ctx.slot_data["options"]["victory_condition"] == 2 or \
+            ctx.slot_data["options"]["victory_condition"] == 3 or ctx.slot_data["options"]["victory_condition"] == 4 or \
+            ctx.slot_data["options"]["victory_condition"] == 6:
+                locs1 = mumbo_tokens_loc(locs1, ctx.slot_data["options"]["victory_condition"])
 
         if len(locs1) > 0:
             await ctx.send_msgs([{
@@ -990,8 +981,8 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
 
         #GAME VICTORY
         #Beat Hag-1
-        if hag == True and (ctx.slot_data["victory_condition"] == 0 or ctx.slot_data["victory_condition"] == 4 or\
-            ctx.slot_data["victory_condition"] == 6) and not ctx.finished_game:
+        if hag == True and (ctx.slot_data["options"]["victory_condition"] == 0 or ctx.slot_data["options"]["victory_condition"] == 4 or\
+            ctx.slot_data["options"]["victory_condition"] == 6) and not ctx.finished_game:
             await ctx.send_msgs([{
                 "cmd": "StatusUpdate",
                 "status": 30
@@ -1000,14 +991,14 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
             ctx._set_message("You have completed your goal", None)
 
         #Mumbo Tokens
-        if (ctx.slot_data["victory_condition"] == 1 or ctx.slot_data["victory_condition"] == 2) and not ctx.finished_game:
+        if (ctx.slot_data["options"]["victory_condition"] == 1 or ctx.slot_data["options"]["victory_condition"] == 2) and not ctx.finished_game:
             mumbo_tokens = 0
             for networkItem in ctx.items_received:
                 if networkItem.item == 1230798:
                     mumbo_tokens += 1
-                    if ((ctx.slot_data["victory_condition"] == 1 and mumbo_tokens >= ctx.slot_data["minigame_hunt_length"]) or
-                        (ctx.slot_data["victory_condition"] == 2 and mumbo_tokens >= ctx.slot_data["boss_hunt_length"]) or
-                        (ctx.slot_data["victory_condition"] == 3 and mumbo_tokens >= ctx.slot_data["jinjo_family_rescue_length"])):
+                    if ((ctx.slot_data["options"]["victory_condition"] == 1 and mumbo_tokens >= ctx.slot_data["options"]["minigame_hunt_length"]) or
+                        (ctx.slot_data["options"]["victory_condition"] == 2 and mumbo_tokens >= ctx.slot_data["options"]["boss_hunt_length"]) or
+                        (ctx.slot_data["options"]["victory_condition"] == 3 and mumbo_tokens >= ctx.slot_data["options"]["jinjo_family_rescue_length"])):
                         await ctx.send_msgs([{
                             "cmd": "StatusUpdate",
                             "status": 30
@@ -1015,24 +1006,24 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
                         ctx.finished_game = True
                         ctx._set_message("You have completed your goal", None)
 
-        if (ctx.current_map == 401 and ctx.slot_data["victory_condition"] == 5 and not ctx.finished_game):
+        if (ctx.current_map == 401 and ctx.slot_data["options"]["victory_condition"] == 5 and not ctx.finished_game):
             mumbo_tokens = 0
             for networkItem in ctx.items_received:
                 if networkItem.item == 1230798:
                     mumbo_tokens += 1
-                    if (mumbo_tokens >= ctx.slot_data["token_hunt_length"]):
+                    if (mumbo_tokens >= ctx.slot_data["options"]["token_hunt_length"]):
                         await ctx.send_msgs([{
                             "cmd": "StatusUpdate",
                             "status": 30
                         }])
                         ctx.finished_game = True
 
-        if (ctx.current_map == 401 and ctx.slot_data["victory_condition"] == 3 and not ctx.finished_game):
+        if (ctx.current_map == 401 and ctx.slot_data["options"]["victory_condition"] == 3 and not ctx.finished_game):
             mumbo_tokens = 0
             for networkItem in ctx.items_received:
                 if networkItem.item == 1230798:
                     mumbo_tokens += 1
-                    if (mumbo_tokens >= ctx.slot_data["jinjo_family_rescue_length"]):
+                    if (mumbo_tokens >= ctx.slot_data["options"]["jinjo_family_rescue_length"]):
                         await ctx.send_msgs([{
                             "cmd": "StatusUpdate",
                             "status": 30
@@ -1241,14 +1232,14 @@ def close_program():
     program.kill()
     program = None
 
-def launch(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def launch(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """
     Launch the client
     """
     logging.getLogger("Banjo-Tooie Client")
 
     async def main():
-        ctx = BanjoTooieContext(server_address, slot_name, password, ready_callback, error_callback)
+        ctx = BanjoTooieContext(server_address, password, ready_callback, error_callback)
         if ctx._can_takeover_existing_gui():
             await ctx._takeover_existing_gui() 
         else:
@@ -1285,9 +1276,9 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
             error_callback()
 
 
-def main(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def main(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, slot_name, password, ready_callback, error_callback)
+    launch(server_address, password, ready_callback, error_callback)
 
 
 if __name__ == "__main__":
